Index: src/crankshaft/arm64/lithium-codegen-arm64.cc |
diff --git a/src/crankshaft/arm64/lithium-codegen-arm64.cc b/src/crankshaft/arm64/lithium-codegen-arm64.cc |
index 292014a5d53d3638880363f01cf414934d0cd022..ecc5afd08f406b06694222d9ba94a79ec0468c8b 100644 |
--- a/src/crankshaft/arm64/lithium-codegen-arm64.cc |
+++ b/src/crankshaft/arm64/lithium-codegen-arm64.cc |
@@ -3471,11 +3471,13 @@ void LCodeGen::DoLoadKeyedFixed(LLoadKeyedFixed* instr) { |
__ B(ne, &done); |
if (info()->IsStub()) { |
// A stub can safely convert the hole to undefined only if the array |
// protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise |
// it needs to bail out. |
- __ LoadRoot(result, Heap::kArrayProtectorRootIndex); |
+ __ LoadRoot(result, Heap::kArrayElementsProtectorRootIndex); |
__ Ldr(result, FieldMemOperand(result, Cell::kValueOffset)); |
- __ Cmp(result, Operand(Smi::FromInt(Isolate::kArrayProtectorValid))); |
+ __ Cmp(result, |
+ Operand(Smi::FromInt(Isolate::kArrayElementsProtectorValid))); |
DeoptimizeIf(ne, instr, Deoptimizer::kHole); |
} |
__ LoadRoot(result, Heap::kUndefinedValueRootIndex); |
@@ -3471,11 +3471,13 @@ void LCodeGen::DoLoadKeyedFixed(LLoadKeyedFixed* instr) { |
if (info()->IsStub()) { |
// A stub can safely convert the hole to undefined only if the array |
- // protector cell contains (Smi) Isolate::kArrayProtectorValid. Otherwise |
+ // protector cell contains (Smi) Isolate::kArrayElementsProtectorValid. |
+ // Otherwise |
// it needs to bail out. |